<?php
// t@CXVEۑ
$filename = $MOWIKI_DATA.encode($gIn['title']).'.txt';

// XV`FbN
if (file_exists($filename)) {
  if (filemtime($filename) > $gIn['ts']) {
	// G[
	print "ERROR<br>XV`FbNɂЂ܂<br>uEU̖߂Ŗ߂ĉ";
	exit;
  }
}

if (file_exists($filename)) { // t@C݂ꍇ
  // x폜
  unlink($filename);
}

// ϊ
$gOut['body'] = $gIn['body'];
$gOut['body'] = preg_replace("/$MOWIKI_DATE/", date($MOWIKI_DATE_FORMAT), $gOut['body']);
$gOut['body'] = preg_replace("/$MOWIKI_TIME/", date($MOWIKI_TIME_FORMAT), $gOut['body']);

// t@Cɏ
$fp = fopen($filename, 'a+');
fputs($fp, $gOut['body']);
fclose($fp);

?>